@@ -9,7 +9,6 @@ var mysteryShipDeployedThisLevel = false;
 var aliendirection = 1;
 
 var aliens = new Array(10*5);
-var state = "STOPPED";
 
 var bombs = new Array(10); //Max of 10 bombs on screen at one time
 var score = 0;
@@ -22,14 +21,9 @@ var livesindication = new Array(startlives - 1);
 var lives;
 
 function cmdNotRunning() {
-    state = "NOTRUNNING";
+    gameState = "NOTRUNNING";
     level = 0;
 
-    //Show the settings button when the level starts
-    settingspanel.state = "HIDDEN";
-    hiscorepanel.state = "HIDDEN";
-    menupanel.state = "HIDDEN";
-
     bunker1.demolish();
     bunker2.demolish();
     bunker3.demolish();
@@ -66,8 +60,14 @@ function cmdNewGame() {
 }
 
 function cmdRunning() {
-    state = "RUNNING";
-    board.hideMessage();
+    gameState = "RUNNING";
+
+    //Hide all panels
+    messagecontainer.state = "HIDDEN"
+    settingspanel.state = "HIDDEN";
+    hiscorepanel.state = "HIDDEN";
+    menupanel.state = "HIDDEN";
+    globalhiscorepanel.state = "HIDDEN";
 
     //Start the animation timers
     heartbeat.running = true;
@@ -75,7 +75,7 @@ function cmdRunning() {
 }
 
 function cmdLifeLost() {
-    state = "LIFELOST";
+    gameState = "LIFELOST";
     lives--;
     if (livesindication[lives - 1]) {
         livesindication[lives - 1].destroy();
@@ -90,7 +90,7 @@ function cmdLifeLost() {
 }
 
 function cmdDead() {
-    state = "DEAD"
+    gameState = "DEAD"
 
     //Stop the animation timers
     heartbeat.running = false;
@@ -105,15 +105,10 @@ function cmdDead() {
 
     board.displayMessage("GAME OVER");
 
-    //Show the seetings button when the game ends
-    settingspanel.state = "HIDDEN";
-    hiscorepanel.state = "HIDDEN";
-    menupanel.state = "HIDDEN"
-
     board.addNewScore(level, score);
     hiscorepanel.refreshScores();
 
-    deadtimer.start();
+    deadtimer.restart();
 }
 
 function cmdResume() {
@@ -121,7 +116,7 @@ function cmdResume() {
 }
 
 function cmdLevelComplete() {
-    state = "LEVELCOMPLETE";
+    gameState = "LEVELCOMPLETE";
 
     board.displayMessage("Level " + level + " complete");
 
@@ -148,16 +143,11 @@ function cmdLevelComplete() {
 }
 
 function cmdStartNewLevel() {
-    state = "LEVELSTARTING";
+    gameState = "LEVELSTARTING";
 
     level++;
     leveltext.text = "Level: " + level;
 
-    //Hide the panels when the level starts
-    settingspanel.state = "HIDDEN";
-    hiscorepanel.state = "HIDDEN";
-    menupanel.state = "HIDDEN";
-
     bunker1.build();
     bunker2.build();
     bunker3.build();
@@ -183,7 +173,7 @@ function cmdStartNewLevel() {
 }
 
 function cmdPause() {
-    state = "PAUSED";
+    gameState = "PAUSED";
     board.displayMessage("Paused");
 
     //Start the animation timers
@@ -206,13 +196,13 @@ function screenTap() {
         return;
     }
 
-    if (state == "NOTRUNNING" && !deadtimer.running) {
+    if (gameState == "NOTRUNNING") {
          cmdNewGame();
-    } else if (state == "LIFELOST" || state == "PAUSED") {
+    } else if (gameState == "LIFELOST" || gameState == "PAUSED") {
         cmdResume();
-    } else if (state == "LEVELCOMPLETE") {
+    } else if (gameState == "LEVELCOMPLETE") {
         cmdStartNewLevel();
-    } else if (state == "RUNNING") {
+    } else if (gameState == "RUNNING") {
          fire();
     }
 }
@@ -361,7 +351,7 @@ function fire()
 }
 
 function mainEvent() {
-    if (state == "RUNNING") {
+    if (gameState == "RUNNING") {
         move();
         moveBombs();
         moveBullet();
@@ -408,7 +398,7 @@ function moveBullet() {
 }
 
 function checkComplete() {
-    if (state == "RUNNING") {
+    if (gameState == "RUNNING") {
         var count = 0;
         for (var i=0; i<50; i++) {
             if(aliens[i]) {
